@@ -79,6 +79,12 @@ impl<M> Condition<M> for ClosureCondition<M> {
     }
 }
 
+impl<M> std::fmt::Debug for ClosureCondition<M> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("ClosureCondition").finish()
+    }
+}
+
 /// Condition that wraps another condition and inverts/negates its result.
 ///
 /// # Example
@@ -110,6 +116,12 @@ impl<M> Condition<M> for ConditionInvert<M> {
     }
 }
 
+impl<M> std::fmt::Debug for ConditionInvert<M> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("ConditionInvert").finish()
+    }
+}
+
 /// Condition that wraps [`Consideration`] and converts it into condition.
 ///
 /// Returns true if consideration returns score greater than [`ConsiderationCondition::threshold`]
@@ -149,3 +161,11 @@ impl<M> Condition<M> for ConsiderationCondition<M> {
         self.consideration.score(memory) > self.threshold
     }
 }
+
+impl<M> std::fmt::Debug for ConsiderationCondition<M> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("ConsiderationCondition")
+            .field("threshold", &self.threshold)
+            .finish()
+    }
+}
