@@ -82,6 +82,12 @@ impl<M> Consideration<M> for ClosureConsideration<M> {
     }
 }
 
+impl<M> std::fmt::Debug for ClosureConsideration<M> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("ClosureConsideration").finish()
+    }
+}
+
 /// Consideration uses [`ScoreMapping`] to remap score of wrapped consideration.
 ///
 /// # Example
@@ -134,6 +140,17 @@ where
     }
 }
 
+impl<M, T> std::fmt::Debug for ConsiderationRemap<M, T>
+where
+    T: ScoreMapping + std::fmt::Debug,
+{
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("ConsiderationRemap")
+            .field("mapping", &self.mapping)
+            .finish()
+    }
+}
+
 /// Consideration wraps [`Condition`] and converts it into consideration.
 ///
 /// If condition returns true, it gives score of [`ConditionConsideration::positive`], if not then
@@ -192,3 +209,12 @@ impl<M> Consideration<M> for ConditionConsideration<M> {
         }
     }
 }
+
+impl<M> std::fmt::Debug for ConditionConsideration<M> {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("ConditionConsideration")
+            .field("positive", &self.positive)
+            .field("negative", &self.negative)
+            .finish()
+    }
+}
