@@ -77,6 +77,17 @@ impl<M, K> MachineryChange<M, K> {
     }
 }
 
+impl<M, K> std::fmt::Debug for MachineryChange<M, K>
+where
+    K: std::fmt::Debug,
+{
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("MachineryChange")
+            .field("to", &self.to)
+            .finish()
+    }
+}
+
 /// Defines machinery state with task to run and changes that can happen for this state.
 pub struct MachineryState<M = (), K = DefaultKey> {
     task: Box<dyn Task<M>>,
@@ -126,6 +137,17 @@ impl<M, K> MachineryState<M, K> {
     }
 }
 
+impl<M, K> std::fmt::Debug for MachineryState<M, K>
+where
+    K: std::fmt::Debug,
+{
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("MachineryState")
+            .field("changes", &self.changes)
+            .finish()
+    }
+}
+
 /// Machinery (a.k.a. Finite State Machine).
 ///
 /// Finite state machines are sets of states with possible transitions between them. Each transition
@@ -354,10 +376,22 @@ where
     }
 }
 
+impl<M, K> std::fmt::Debug for Machinery<M, K>
+where
+    K: Clone + Hash + Eq + std::fmt::Debug,
+{
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("Machinery")
+            .field("states", &self.states)
+            .field("active_state", &self.active_state)
+            .finish()
+    }
+}
+
 /// Machinery builder.
 ///
 /// See [`Machinery`].
-pub struct MachineryBuilder<M = (), K = DefaultKey>(HashMap<K, MachineryState<M, K>>);
+pub struct MachineryBuilder<M = (), K = DefaultKey>(pub HashMap<K, MachineryState<M, K>>);
 
 impl<M, K> Default for MachineryBuilder<M, K> {
     fn default() -> Self {
@@ -383,3 +417,14 @@ where
         Machinery::new(self.0)
     }
 }
+
+impl<M, K> std::fmt::Debug for MachineryBuilder<M, K>
+where
+    K: Clone + Hash + Eq + std::fmt::Debug,
+{
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("MachineryBuilder")
+            .field("states", &self.0)
+            .finish()
+    }
+}
