@@ -59,6 +59,7 @@ impl ScoreMapping for dyn Fn(Scalar) -> Scalar {
 /// );
 /// assert_eq!(consideration.score(&()), 0.5);
 /// ```
+#[derive(Debug, Copy, Clone)]
 pub struct NoScoreMapping;
 
 impl ScoreMapping for NoScoreMapping {
@@ -96,6 +97,12 @@ impl ScoreMapping for ClosureScoreMapping {
     }
 }
 
+impl std::fmt::Debug for ClosureScoreMapping {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("ClosureScoreMapping").finish()
+    }
+}
+
 /// Chains two score mappings so [`Self::first`] remaps input score and then [`Self::second`] remaps
 /// score got from [`Self::first`]: `second.remap(first.remap(score))`.
 ///
@@ -138,6 +145,19 @@ where
     }
 }
 
+impl<A, B> std::fmt::Debug for ChainedScoreMapping<A, B>
+where
+    A: ScoreMapping + std::fmt::Debug,
+    B: ScoreMapping + std::fmt::Debug,
+{
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("ChainedScoreMapping")
+            .field("first", &self.first)
+            .field("second", &self.second)
+            .finish()
+    }
+}
+
 /// Remaps score from source range ([`Self::from`]) to target range ([`Self::to`]).
 ///
 /// # Example
@@ -168,6 +188,15 @@ impl ScoreMapping for ScoreRemap {
     }
 }
 
+impl std::fmt::Debug for ScoreRemap {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("ScoreRemap")
+            .field("from", &self.from)
+            .field("to", &self.to)
+            .finish()
+    }
+}
+
 /// Applies `1.0 - score`.
 ///
 /// # Example
@@ -188,6 +217,12 @@ impl ScoreMapping for ReverseScoreMapping {
     }
 }
 
+impl std::fmt::Debug for ReverseScoreMapping {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("ReverseScoreMapping").finish()
+    }
+}
+
 /// Applies `1.0 / score`.
 ///
 /// # Example
@@ -208,6 +243,12 @@ impl ScoreMapping for InverseScoreMapping {
     }
 }
 
+impl std::fmt::Debug for InverseScoreMapping {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("InverseScoreMapping").finish()
+    }
+}
+
 /// Applies fast sigmoid function.
 /// See [WolframAlpha](https://www.wolframalpha.com/input/?i2d=true&i=f%5C%2840%29x%5C%2841%29%3D+Divide%5Bx%2C1+%2B+Abs%5Bx%5D%5D).
 pub struct FastSigmoidScoreMapping;
@@ -218,6 +259,12 @@ impl ScoreMapping for FastSigmoidScoreMapping {
     }
 }
 
+impl std::fmt::Debug for FastSigmoidScoreMapping {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("FastSigmoidScoreMapping").finish()
+    }
+}
+
 /// Applies approximated sigmoid function.
 /// See [WolframAlpha](https://www.wolframalpha.com/input/?i2d=true&i=f%5C%2840%29x%5C%2841%29%3D+Divide%5Bx%2CSqrt%5B1+%2B+Power%5Bx%2C2%5D%5D%5D).
 pub struct ApproxSigmoidScoreMapping;
@@ -227,3 +274,9 @@ impl ScoreMapping for ApproxSigmoidScoreMapping {
         score / (1.0 + (score * score).sqrt())
     }
 }
+
+impl std::fmt::Debug for ApproxSigmoidScoreMapping {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("ApproxSigmoidScoreMapping").finish()
+    }
+}
